# Dicom-To-CNN

Install : pip install dicom-to-cnn 

Features : 
- Description of Series content in a huge dataset of DICOM (output JSON descriptor for each series containings main DICOM tags).
- Conversion  :
  - Dicom to Nifti
  - Mask to RTSS and DICOMSeg
  - RTSS to mask
  - DicomSeg to mask 
- PET/CT
  - Conversion Bqml/Counts to SUV and SUL
  - Fusion


#Maintainer  : Salim Kanoun
#Contributors : Thomas Trouillard, Wendy Revailler
